#
# spec file for package python-magic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# PyPI package name is file-magic. Version is taken from setup.py
%define file_magic_version 0.3.0
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global         _miscdir    %{_datadir}/misc
Name:           python-magic
Version:        5.46
Release:        1.2
Summary:        Python module to use libmagic
License:        BSD-3-Clause AND BSD-4-Clause
Group:          Development/Languages/Python
URL:            https://www.darwinsys.com/file/
Source99:       file.spec
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  findutils
BuildRequires:  libtool
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(zlib)
Requires:       libmagic1
Provides:       python-file-magic = %{file_magic_version}
%{expand:%(sed -n -e '/^Source0\?:/,/^BuildRoot:/p' <%{_sourcedir}/file.spec)}
%python_subpackages

%description
This package contains the Python binding that require the magic "file"
interface.

%prep
%{expand:%(sed -n -e '/^%%prep/,/^%%build/p' <%{_sourcedir}/file.spec | sed -e '1d' -e '$d')}
ln -sf README.md python/README

pushd python
%python_build
popd

%install
pushd python
%python_install
popd

%check
export LC_ALL=C.UTF-8
pushd python
%python_flavored_alternatives
%pyunittest -v tests
popd

%files %{python_files}
%doc python/README python/example.py
%{python_sitelib}/magic.py*
%pycache_only %{python_sitelib}/__pycache__
%{python_sitelib}/file_magic-*-py%{python_version}.egg-info

%changelog
* Fri Aug  9 2024 Matej Cepl <mcepl@cepl.eu>
- Don't use `setup.py test`, that is now not allowed.
* Thu May  4 2023 Frederic Crozat <fcrozat@suse.com>
- Add _multibuild to define additional spec files as additional
  flavors.
  Eliminates the need for source package links in OBS.
* Tue Jan 10 2023 Dr. Werner Fink <werner@suse.de>
- Enable tests for python-magic (not python-python-magic)
* Tue Jan 10 2023 Dr. Werner Fink <werner@suse.de>
- Run pre_checkin.sh to get correct source tar ball
* Mon Jan  9 2023 Dr. Werner Fink <werner@suse.de>
- Update to 5.44
* Mon Dec 12 2022 Dirk Müller <dmueller@suse.com>
- switch to pkgconfig(zlib) so that alternative providers can be
  used
* Wed Sep 14 2022 Dr. Werner Fink <werner@suse.de>
- Update to 5.43 due to Dirk
* Sat Mar 19 2022 Dirk Müller <dmueller@suse.com>
- spec-cleaner run
* Tue Oct 19 2021 Dr. Werner Fink <werner@suse.de>
- Update to 5.41
* Sat Apr  3 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 5.40:
  * file 5.40, no changes specific to python-magic
* Wed Jun 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.39
* Tue Dec 17 2019 Dr. Werner Fink <werner@suse.de>
- Correct version of file which is now 5.38
* Mon Oct 14 2019 Dr. Werner Fink <werner@suse.de>
- Let python-magic build with latest rpm
* Wed May 29 2019 Dr. Werner Fink <werner@suse.de>
- Correct version of file which is now 5.37
* Thu Feb 21 2019 Dr. Werner Fink <werner@suse.de>
- Correct version of file which is now 5.36
* Thu Oct 25 2018 Dr. Werner Fink <werner@suse.de>
- Correct version of file which is now 5.35
* Wed Jun 13 2018 werner@suse.de
- Correct version of file which is now 5.33
* Tue Sep 26 2017 jmatejek@suse.com
- converted to singlespec, dropped separate python3-magic spec file
- moved python build instructions from file.spec to python-magic.spec
- do not need to build the binary parts in order to build the python part
- removed inlining of %%defines from file.spec because it is unreliable
  in presence of parametrized macros
- added provides: python-file-magic to comply with the python package
  naming policy
* Wed Apr 20 2016 werner@suse.de
- Add Build Require python-setuptools
* Mon Apr 18 2016 werner@suse.de
- Now it's file 5.26
* Tue Feb 16 2016 rolf@rotkraut.de
- Make the python command a macro.
- Remove %%py_requires.
- Add dependency on libmagic.
* Thu Jan 21 2016 dmueller@suse.com
- add file-5.25-avoid-double-evaluation-in-python-bindings.dif (bsc#949905)
* Sun Oct  4 2015 astieger@suse.com
- file 5.25:
  * add a limit to the length of regex searches
  * fix problems with --parameter
* Tue Jul 14 2015 werner@suse.de
- adapt version in specfile to 5.24
* Thu Jun 11 2015 werner@suse.de
- adapt version in specfile to 5.23
* Tue Jan 20 2015 werner@suse.de
- adapt version in specfile to 5.22
* Wed Dec 17 2014 werner@suse.de
- adapt version in specfile to 5.21
* Mon Oct 13 2014 werner@suse.de
- adapt version in specfile to 5.20
* Wed Jun 25 2014 werner@suse.de
- adapt version in specfile to 5.19
* Fri Feb 28 2014 ro@suse.de
- adapt version in specfile to 5.17
* Sun Feb 23 2014 andreas.stieger@gmx.de
- Update python-magic to file version 5.17 (bug fix release)
  * Count recursion levels through indirect magic
  * Prevent infinite recursion on files with indirect offsets of 0
  * Add -E flag that makes file print filesystem errors to stderr
    and exit.
  * mime printing could print results from multiple magic entries
    if there were multiple matches.
  * in some cases overflow was not detected when computing offsets
    in softmagic.
  * use strcasestr() to for cdf strings
  * reset to the "C" locale while doing regex operations, or case
    insensitive comparisons; this is provisional
* Mon Dec  2 2013 werner@suse.de
- Make it ready for file 5.16
* Tue Oct  1 2013 werner@suse.de
- Make it ready for file 5.15
* Tue Mar 12 2013 idonmez@suse.com
- Run pre_checkin.sh
* Tue Mar 27 2012 aj@suse.de
- ran pre_checkin.sh
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon Aug 29 2011 coolo@novell.com
- ran pre_checkin.sh
* Tue Apr 15 2008 werner@suse.de
- Also change version number in python-magic.spec
* Mon Jan 28 2008 rguenther@suse.de
- Split off from file.
